==> mysql-workbench-community-8.0.12-src.tar.gz: mysql-workbench-community-8.0.12-src/frontend/mac/workbench/WBPluginPanelController.mm <==
/*
 * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
 */

#include "base/geometry.h"
#include "base/string_utilities.h"

#import "WBPluginPanelController.h"

@interface WBPluginPanelController()
{
  NSPanel *_panel;
  WBPluginPanel *_editor;
}

@end

@implementation WBPluginPanelController

- (instancetype)initWithEditor: (WBPluginPanel*)editor
{
  self = [super init];
  if (self != nil && editor != nil)
  {
    NSRect rect = NSZeroRect;
    rect.size = editor.minimumSize;

    _panel = [[NSPanel alloc] initWithContentRect:rect styleMask:0 backing:NSBackingStoreNonretained defer:NO];
    _editor = editor;
    
    _panel.title = _editor.title;
    _panel.contentView = _editor.topView;

    [_editor didOpen];
  }
  return self;
}

- (instancetype)init
{
  return [self initWithEditor: nil];
}

- (void)show:(id)sender
{
  [_panel makeKeyAndOrderFront: nil];
}

- (void)hide:(id)sender
{
}

@end

==> mysql-workbench-community-8.0.33-src.tar.gz: mysql-workbench-community-8.0.33-src/frontend/mac/workbench/WBPluginPanelController.mm <==
/*
 * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
 */

#include "base/geometry.h"
#include "base/string_utilities.h"

#import "WBPluginPanelController.h"

@interface WBPluginPanelController()
{
  NSPanel *_panel;
  WBPluginPanel *_editor;
}

@end

@implementation WBPluginPanelController

- (instancetype)initWithEditor: (WBPluginPanel*)editor
{
  self = [super init];
  if (self != nil && editor != nil)
  {
    NSRect rect = NSZeroRect;
    rect.size = editor.minimumSize;

    _panel = [[NSPanel alloc] initWithContentRect: rect styleMask: 0 backing: NSBackingStoreBuffered defer: NO];
    _editor = editor;
    
    _panel.title = _editor.title;
    _panel.contentView = _editor.topView;

    [_editor didOpen];
  }
  return self;
}

- (instancetype)init
{
  return [self initWithEditor: nil];
}

- (void)show:(id)sender
{
  [_panel makeKeyAndOrderFront: nil];
}

- (void)hide:(id)sender
{
}

@end
